@@ -248,35 +248,6 @@ class LighthouseClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
-    def CreateInstances(self, request):
-        """This API is used to create one or more Lighthouse instances.
-
-        :param request: Request instance for CreateInstances.
-        :type request: :class:`tencentcloud.lighthouse.v20200324.models.CreateInstancesRequest`
-        :rtype: :class:`tencentcloud.lighthouse.v20200324.models.CreateInstancesResponse`
-
-        """
-        try:
-            params = request._serialize()
-            headers = request.headers
-            body = self.call("CreateInstances", params, headers=headers)
-            response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.CreateInstancesResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
     def CreateKeyPair(self, request):
         """This API is used to create a key pair.
 
@@ -780,35 +751,6 @@ class LighthouseClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
-    def DescribeGeneralResourceQuotas(self, request):
-        """This API is used to query the quota information of general resources.
-
-        :param request: Request instance for DescribeGeneralResourceQuotas.
-        :type request: :class:`tencentcloud.lighthouse.v20200324.models.DescribeGeneralResourceQuotasRequest`
-        :rtype: :class:`tencentcloud.lighthouse.v20200324.models.DescribeGeneralResourceQuotasResponse`
-
-        """
-        try:
-            params = request._serialize()
-            headers = request.headers
-            body = self.call("DescribeGeneralResourceQuotas", params, headers=headers)
-            response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DescribeGeneralResourceQuotasResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
     def DescribeInstanceLoginKeyPairAttribute(self, request):
         """This API is used to query the attributes of the default login key of an instance.
 
@@ -839,12 +781,21 @@ class LighthouseClient(AbstractClient):
 
 
     def DescribeInstanceVncUrl(self, request):
-        """This API is used to query the VNC URL of an instance, and the obtained address can be used for VNC login to the instance.
+        """This API is used to query the URL for VNC login.
 
-        * This feature is available to instances in `RUNNING` status.
-        * A VNC URL is only valid for 15 seconds. If you do not access the URL within 15 seconds, it will become invalid, and you will have to query another one.
-        * Once the VNC URL is accessed, it will become invalid, and you will have to query another one if needed.
-        * If the connection is interrupted, up to 30 reconnection requests per minute are allowed.
+        * It does not support `STOPPED` CVMs.
+        * A VNC URL is only valid for 15 seconds. If you do not access the URL within 15 seconds, you will need to query another one.
+        * The VNC URL can be used once only. You need to query a new one if you want to log in again.
+        * Up to 30 re-connection attempts allowed in one minute.
+        After you get the value of `InstanceVncUrl`, you need to append `InstanceVncUrl=xxxx` to the end of the link `https://img.qcloud.com/qcloud/app/active_vnc/index.html?`.
+
+          - `InstanceVncUrl`: Its value will be returned after the API is successfully called.
+
+            The final URL can be in the following formats:
+
+        ```
+        https://img.qcloud.com/qcloud/app/active_vnc/index.html?InstanceVncUrl=wss%3A%2F%2Fbjvnc.qcloud.com%3A26789%2Fvnc%3Fs%3DaHpjWnRVMFNhYmxKdDM5MjRHNlVTSVQwajNUSW0wb2tBbmFtREFCTmFrcy8vUUNPMG0wSHZNOUUxRm5PMmUzWmFDcWlOdDJIbUJxSTZDL0RXcHZxYnZZMmRkWWZWcEZia2lyb09XMzdKNmM9
+        ```
 
         :param request: Request instance for DescribeInstanceVncUrl.
         :type request: :class:`tencentcloud.lighthouse.v20200324.models.DescribeInstanceVncUrlRequest`
@@ -872,40 +823,6 @@ class LighthouseClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
-    def DescribeInstances(self, request):
-        """This API is used to query the details of one or multiple instances.
-
-        * You can query the details of an instance according to its ID, name, or private IP.
-        * For more information on filters, please see [Filters](https://intl.cloud.tencent.com/document/product/1207/47576?from_cn_redirect=1#Filter).
-        * If no parameter is defined, the status of a certain number of instances under the current account will be returned. The number is specified by `Limit` and is 20 by default.
-        * The latest operation (LatestOperation) and the latest operation status (LatestOperationState) of the instance can be queried.
-
-        :param request: Request instance for DescribeInstances.
-        :type request: :class:`tencentcloud.lighthouse.v20200324.models.DescribeInstancesRequest`
-        :rtype: :class:`tencentcloud.lighthouse.v20200324.models.DescribeInstancesResponse`
-
-        """
-        try:
-            params = request._serialize()
-            headers = request.headers
-            body = self.call("DescribeInstances", params, headers=headers)
-            response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DescribeInstancesResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
     def DescribeInstancesDeniedActions(self, request):
         """This API is used to query the list of operation limits of one or more instances.
 
@@ -1463,35 +1380,6 @@ class LighthouseClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
-    def InquirePriceRenewInstances(self, request):
-        """This API is used to query the price of renewed instance.
-
-        :param request: Request instance for InquirePriceRenewInstances.
-        :type request: :class:`tencentcloud.lighthouse.v20200324.models.InquirePriceRenewInstancesRequest`
-        :rtype: :class:`tencentcloud.lighthouse.v20200324.models.InquirePriceRenewInstancesResponse`
-
-        """
-        try:
-            params = request._serialize()
-            headers = request.headers
-            body = self.call("InquirePriceRenewInstances", params, headers=headers)
-            response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.InquirePriceRenewInstancesResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
     def ModifyBlueprintAttribute(self, request):
         """This API is used to modify an image attribute.
 
