@@ -17,6 +17,9 @@
 # Request timed out
 INTERNALERROR_ACTIONREADTIMEOUT = 'InternalError.ActionReadTimeout'
 
+# 
+INTERNALERROR_ADDNEWNODEERROR = 'InternalError.AddNewNodeError'
+
 # Failed to create the APM resource
 INTERNALERROR_CREATEAPMRESOURCEERROR = 'InternalError.CreateApmResourceError'
 
@@ -29,6 +32,9 @@ INTERNALERROR_CREATESERVICEERROR = 'InternalError.CreateServiceError'
 # The server is busy. Retry later.
 INTERNALERROR_DEFAULTINTERNALERROR = 'InternalError.DefaultInternalError'
 
+# 
+INTERNALERROR_DELETEINGRESSERROR = 'InternalError.DeleteIngressError'
+
 # Failed to invoke the version deployment
 INTERNALERROR_DEPLOYVERSIONERROR = 'InternalError.DeployVersionError'
 
@@ -38,13 +44,16 @@ INTERNALERROR_DESCRIBERUNPODLISTERROR = 'InternalError.DescribeRunPodListError'
 # Failed to query the list of ingress associated with the service.
 INTERNALERROR_DESCRIBESERVICEINGRESSERROR = 'InternalError.DescribeServiceIngressError'
 
+# 
+INTERNALERROR_DESCRIBESERVICELISTERROR = 'InternalError.DescribeServiceListError'
+
 # Failed to restart
 INTERNALERROR_RESTARTAPPLICATIONERROR = 'InternalError.RestartApplicationError'
 
 # Failed to update the ingress
 INTERNALERROR_UPDATEINGRESSERROR = 'InternalError.UpdateIngressError'
 
-# 
+# Only one auto scaler can be specified.
 INVALIDPARAMETERVALUE_AUTOSCALERLARGERTHANONE = 'InvalidParameterValue.AutoScalerLargerThanOne'
 
 # The version number is invalid.
@@ -62,6 +71,9 @@ INVALIDPARAMETERVALUE_NAMESPACEREACHMAXIMUM = 'InvalidParameterValue.NamespaceRe
 # Failed to create the environment. The upper limit of environment is reached.
 INVALIDPARAMETERVALUE_NAMESPACERESOURCEREACHMAXIMUM = 'InvalidParameterValue.NamespaceResourceReachMaximum'
 
+# 
+INVALIDPARAMETERVALUE_SERVICEPODREACHMAXIMUM = 'InvalidParameterValue.ServicePodReachMaximum'
+
 # Linkage tracing is not available for non-JAVA applications.
 INVALIDPARAMETERVALUE_TRAITSTRACINGNOTSUPPORTED = 'InvalidParameterValue.TraitsTracingNotSupported'
 
@@ -74,7 +86,7 @@ MISSINGPARAMETER_DEPLOYVERSIONNULL = 'MissingParameter.DeployVersionNull'
 # The environment ID can not be left empty.
 MISSINGPARAMETER_NAMESPACEIDNULL = 'MissingParameter.NamespaceIdNull'
 
-# 
+# The package name cannot be left empty.
 MISSINGPARAMETER_PKGNAMENULL = 'MissingParameter.PkgNameNull'
 
 # The service ID cannot be empty.
